diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 64fdc8f0c6c9b69e1e014c80e108e76844ea98f9..fe34e0767ed65d2b5758878284f2b0923463e4b9 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -4,7 +4,7 @@ before_script:
   - apt update && apt install -y gcc
   - conda init bash && source ~/.bashrc && echo $CONDA_DEFAULT_ENV
   - conda env create -f install/environment.root.yml
-  - conda activate rhea && echo $CONDA_DEFAULT_ENV
+  - conda activate zarp && echo $CONDA_DEFAULT_ENV
   - conda env update -f install/environment.dev.yml
 
 test:
diff --git a/README.md b/README.md
index c8dca57c41d6a461ce6617bd42ddca6604f5634e..ed3941e4e1af8c952f0222fc688079c0d4528afa 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-# Rhea pipeline
+# ZARP pipeline
 
 [Snakemake][snakemake] workflow for general purpose RNA-Seq library annotation
 developed by the [Zavolan lab][zavolan-lab].
@@ -32,8 +32,8 @@ Traverse to the desired path on your file system, then clone the repository and
 move into it with:
 
 ```bash
-git clone ssh://git@git.scicore.unibas.ch:2222/zavolan_group/pipelines/rhea.git
-cd rhea
+git clone ssh://git@git.scicore.unibas.ch:2222/zavolan_group/pipelines/zarp.git
+cd zarp
 ```
 
 ### Installing Conda
@@ -90,7 +90,7 @@ conda env create -f install/environment.root.yml
 Activate the Conda environment with:
 
 ```bash
-conda activate rhea
+conda activate zarp
 ```
 
 ### Installing non-essential dependencies
diff --git a/Snakefile b/Snakefile
index 450f545fb2fc330dd881f02e0ae8bb4ed3ec003e..909ad8ab7f94956cae0575e74edd5045ec5d26f0 100644
--- a/Snakefile
+++ b/Snakefile
@@ -1117,7 +1117,7 @@ rule prepare_multiqc_config:
             workflow.basedir,
             "workflow",
             "scripts",
-            "rhea_multiqc_config.py")
+            "zarp_multiqc_config.py")
 
     output:
         multiqc_config = os.path.join(
diff --git a/install/environment.dev.yml b/install/environment.dev.yml
index ab5c30ac6c60c998193981c084150d4bc907b41d..3fa2e724fd16391bdb210d3afb4aeaec647b450a 100644
--- a/install/environment.dev.yml
+++ b/install/environment.dev.yml
@@ -1,4 +1,4 @@
-name: rhea
+name: zarp
 channels:
   - bioconda
   - conda-forge
diff --git a/install/environment.root.yml b/install/environment.root.yml
index 7017feb85a963093898030ae135b094244c4774d..20075baa970393f90ce0d61abd0083953b916946 100644
--- a/install/environment.root.yml
+++ b/install/environment.root.yml
@@ -1,4 +1,4 @@
-name: rhea
+name: zarp
 channels:
   - conda-forge
   - defaults
diff --git a/install/environment.yml b/install/environment.yml
index 4fa641ab259484f747f4af4d70f5464d41649aab..1f69c6131bcafbb992a925837733caacc363183f 100644
--- a/install/environment.yml
+++ b/install/environment.yml
@@ -1,4 +1,4 @@
-name: rhea
+name: zarp
 channels:
   - defaults
 dependencies:
diff --git a/pipeline_documentation.md b/pipeline_documentation.md
index 0a29c8cd2608fb12fdc96a86309073cb5384cebd..6dea08609c37872cedd22feebd3eacee282a4d16 100644
--- a/pipeline_documentation.md
+++ b/pipeline_documentation.md
@@ -1,4 +1,4 @@
-# Rhea: workflow documentation
+# ZARP: workflow documentation
 
 This document describes the individual steps of the workflow. For instructions
 on installation and usage please see [here](README.md).
diff --git a/scripts/prepare_inputs.py b/scripts/prepare_inputs.py
index 1efc031f7767dafb393e8a549c3f6ce1fcd42443..5bcfb9bfef4de9e64f4dabc1c7dfb4b292966639 100755
--- a/scripts/prepare_inputs.py
+++ b/scripts/prepare_inputs.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
 """Create input table and config for Rhea."""
 
 import argparse
 from functools import partial
@@ -79,14 +79,14 @@ def parse_cli_args() -> argparse.Namespace:
         "--output-table",
         type=argparse.FileType('w'),
         default="samples.tsv",
-        help="output sample table for use in Rhea (default: %(default)s)",
+        help="output sample table for use in ZARP (default: %(default)s)",
         metavar="FILE",
     )
     io.add_argument(
         "--config-file",
         type=argparse.FileType('w'),
         default="config.yaml",
-        help="output Snakemake configuration file for use in Rhea (default: "
+        help="output Snakemake configuration file for use in ZARP (default: "
              "%(default)s)",
         metavar="FILE",
     )
@@ -94,7 +94,7 @@ def parse_cli_args() -> argparse.Namespace:
         "--output-dir",
         type=str,
         default=os.getcwd(),
-        help="directory to which Rhea results and logs are to be written "
+        help="directory to which ZARP results and logs are to be written "
              "(default: %(default)s)",
         metavar="DIR",
     )
@@ -453,7 +453,7 @@ def expand_path(
 
 def main(args):
     """
     Create input table and config for Rhea.
     """
     setup_logging(
         logger=logger,
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-"""Create input table and config for Rhea."""
+"""Create input table and config for ZARP."""
 
 import argparse
@@ -453,7 +453,7 @@ def expand_path(
 def main(args):
     """
-    Create input table and config for Rhea.
+    Create input table and config for ZARP.
     """
     setup_logging(
diff --git a/workflow/scripts/rhea_multiqc_config.py b/workflow/scripts/zarp_multiqc_config.py
similarity index 97%
rename from workflow/scripts/rhea_multiqc_config.py
rename to workflow/scripts/zarp_multiqc_config.py
index 89dbfb2e4fc78ea08e8703a0aa70125adeffff8e..68d2d6cf0b10f405db0eee2edf66d72898eb69b9 100644
--- a/workflow/scripts/rhea_multiqc_config.py
+++ b/workflow/scripts/zarp_multiqc_config.py
@@ -3,7 +3,7 @@
 # -----------------------------------------------------------------------------
 # Author : Maria Katsantoni, Maciek Bak
 # Company: Mihaela Zavolan, Biozentrum, Basel
 # This script is part of the Zavolan lab Rhea pipeline.
 # In this script the config file used by multiqc
 # (https://multiqc.info) is created.
 # -----------------------------------------------------------------------------
@@ -62,9 +62,9 @@ def main():
         parser.print_help()
         sys.exit(1)
 
-    title = "Rhea"
+    title = "ZARP"
     subtitle = "RNA-Seq processing pipeline developed by Zavolan Lab"
-    logo_title = 'Rhea'
+    logo_title = "ZARP"
     project_type = "Snakemake workflow"
     analysis_type = "RNA-seq"
@@ -3,7 +3,7 @@
 # Author : Maria Katsantoni, Maciek Bak
 # Company: Mihaela Zavolan, Biozentrum, Basel
-# This script is part of the Zavolan lab Rhea pipeline.
+# This script is part of the Zavolan lab ZARP pipeline.
 # In this script the config file used by multiqc
 # (https://multiqc.info) is created.